@@ -1,5 +1,5 @@
 from smoltools.fret0.main import path_to_distances, chain_to_distances
 from smoltools.fret0.efficiency import e_fret_between_conformations
-from smoltools.calculate.distance import pairwise_distance_between_conformations
+from smoltools.calculate.distance import pairwise_distances_between_conformations
 
 import smoltools.fret0.plots as plots
